@@ -1,13 +1,20 @@
 /*
- * This file or a portion of this file is licensed under the
- * terms of the Globus Toolkit Public License, found at
- * http://www.globus.org/toolkit/download/license.html.
- * If you redistribute this file, with or without
- * modifications, you must include this notice in the file.
+ * Copyright 1999-2014 University of Chicago
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
-#include "globus_config.h"
 
-#ifdef TARGET_ARCH_WIN32
+#ifdef _WIN32
 
 #include "globus_i_xio_win32.h"
 
@@ -266,7 +273,7 @@ globus_l_xio_win32_event_remove(
     globus_l_xio_win32_event_thread_t * thread,
     globus_l_xio_win32_event_entry_t *  entry);
 
-/**
+/*
  * this returns -1 or the prior index of the entry replacing this one
  */
 static
@@ -339,7 +346,7 @@ globus_l_xio_win32_event_thread(
             }
             else if(!globus_list_empty(thread->pending_posts))
             {
-                /**
+                /*
                  * dispatch all pending posts
                  */
                 globus_l_xio_win32_event_entry_t * consumed;
@@ -364,7 +371,7 @@ globus_l_xio_win32_event_thread(
             }
             else
             {
-                /**
+                /*
                  * dispatch consumed event and check rest with 0 timeout
                  * The added complexity here ensures we don't starve anyone
                  */
@@ -377,7 +384,7 @@ globus_l_xio_win32_event_thread(
                         
                     if(replacement < 0 || replacement >= count)
                     {
-                        /**
+                        /*
                          * either wasn't removed or the replacement is
                          * outside the range I am processing in this iteration
                          * 
@@ -387,7 +394,7 @@ globus_l_xio_win32_event_thread(
                     }
                     else
                     {
-                        /**
+                        /*
                          * replacement is in my range, reduce count and
                          * maintain current index.
                          */
@@ -743,7 +750,7 @@ globus_i_xio_win32_event_register(
     
     if(do_wakeup)
     {
-        /**
+        /*
          * I do this outside the lock to avoid immediate contention in the
          * thead.  This leaves the possibility that the thread is gone
          * before this call, resulting in segv.  However, this is only
@@ -897,4 +904,4 @@ globus_i_xio_win32_event_post(
     
     GlobusXIOSystemDebugExit();
 }
-#endif /* TARGET_ARCH_WIN32 */
+#endif /* _WIN32 */
